# PyAstronautics

PyAstronautics is a Python package designed for astronautical engineers, providing tools for spacecraft design analysis, simulations, and optimization. This package includes features for modeling the space environment, astrodynamics, spacecraft controls and mission design.

Ad Astra! 💫

![Test Status](https://img.shields.io/github/actions/workflow/status/eduardo-ocampo/pyastronautics/test-package.yml?branch=main&style=flat-square&logo=github&logoColor=white&label=Pytest&color=00A86B)
![Documentation Status](https://img.shields.io/github/actions/workflow/status/eduardo-ocampo/pyastronautics/sphinx-docs.yml?branch=main&style=flat-square&logo=github&logoColor=white&label=Build%20%26%20Deploy%20Documentation&color=00A86B)
![PyPI - Version](https://img.shields.io/pypi/v/PyAstronautics?style=flat-square&logo=python&logoColor=white&color=blue)
![GitHub License](https://custom-icon-badges.demolab.com/github/license/eduardo-ocampo/pyastronautics?style=flat-square&logo=law&logoColor=white&color=blue)

[![Made With](https://img.shields.io/badge/Made_With-Stardust-pink?style=flat-square&logo=electron&logoColor=white)](https://github.com/eduardo-ocampo/PyAstronautics)
[![USC Astro](https://custom-icon-badges.demolab.com/badge/USC-Astro-red?style=flat-square&logo=mortar-board&logoColor=white&labelColor=990000&color=FFCC00)](https://viterbigradadmission.usc.edu/programs/masters/msprograms/astronautical-engineering/)

# Installation 

Installers for the latest released version are available at the [Python Package Index (PyPI)](https://pypi.org/project/pyastronautics/)

```shell
pip install pyastronautics
```

# Documentation

The long-form documentation and examples for this project are hosted on Github Pages: [PyAstronautics Documentation](https://eduardo-ocampo.github.io/PyAstronautics/)

## License

Copyright 2024 Eduardo Ocampo

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
